# pymola

A python/modelica based simulation environment.

[![Build Status](https://travis-ci.org/jgoppert/pymola.svg)](https://travis-ci.org/jgoppert/pymola)
[![Coverage Status](https://img.shields.io/coveralls/jgoppert/pymola.svg)](https://coveralls.io/r/jgoppert/pymola)

## Examples
[Simple IPython Notebook Example](test/Spring.ipynb)

## Roadmap

### Completed Tasks

* hello world compilation
* Project setup.
* Unit testing for parsers.
* Parsing basic hello world example.
* Travis continuous integration testing setup.
* Coveralls coverage testing setup.

### TODO

* add more complicated test cases
* resolve grammar issues
* support more of modelica language
* add modelica magic support for ipython?

<!--- vim:ts=4:sw=4:expandtab:
!-->
